ConstellationToEmbedderMsg

Enum ConstellationToEmbedderMsg 

pub enum ConstellationToEmbedderMsg {
Show 13 variants ShutdownComplete, ReportProfile(Vec<u8>), WebViewBlurred, HistoryTraversalComplete(WebViewId, TraversalId), MediaSessionEvent(WebViewId, MediaSessionEvent), Panic(WebViewId, String, Option<String>), WebViewFocused(WebViewId, bool), InputEventsHandled(WebViewId, Vec<InputEventOutcome>), WebViewClosed(WebViewId), FinishJavaScriptEvaluation(JavaScriptEvaluationId, Result<JSValue, JavaScriptEvaluationError>), AllowOpeningWebView(WebViewId, GenericSender<Option<NewWebViewDetails>>), AllowNavigationRequest(WebViewId, PipelineId, ServoUrl), HistoryChanged(WebViewId, Vec<ServoUrl>, usize),
}
Messages sent from the Constellation to the embedder.

Variants



ShutdownComplete

Informs the embedder that the constellation has completed shutdown. Required because the constellation can have pending calls to make (e.g. SetFrameTree) at the time that we send it an ExitMsg.



ReportProfile(Vec<u8>)

Report a complete sampled profile



WebViewBlurred

All webviews lost focus for keyboard events.



HistoryTraversalComplete(WebViewId, TraversalId)

A history traversal operation completed.



MediaSessionEvent(WebViewId, MediaSessionEvent)

Notifies the embedder about media session events (i.e. when there is metadata for the active media session, playback state changes…).



Panic(WebViewId, String, Option<String>)

A pipeline panicked. First string is the reason, second one is the backtrace.



WebViewFocused(WebViewId, bool)

A webview potentially gained focus for keyboard events. If the boolean value is false, the webiew could not be focused.



InputEventsHandled(WebViewId, Vec<InputEventOutcome>)

Inform the embedding layer that a particular InputEvent was handled by Servo and the embedder can continue processing it, if necessary.



WebViewClosed(WebViewId)

A webview was destroyed.



FinishJavaScriptEvaluation(JavaScriptEvaluationId, Result<JSValue, JavaScriptEvaluationError>)

Inform the embedding layer that a JavaScript evaluation has finished with the given result.



AllowOpeningWebView(WebViewId, GenericSender<Option<NewWebViewDetails>>)

Whether or not to allow script to open a new tab/browser



AllowNavigationRequest(WebViewId, PipelineId, ServoUrl)

Whether or not to allow a pipeline to load a url.



HistoryChanged(WebViewId, Vec<ServoUrl>, usize)

The history state has changed.