Crate servo_constellation

Crate servo_constellation 

Structs

Constellation
The Constellation itself. In the servo browser, there is one constellation, which maintains all of the browser global data. In embedded applications, there may be more than one constellation, which are independent of each other.
EventLoop
https://html.spec.whatwg.org/multipage/#event-loop
FromEmbedderLogger
A logger directed at the constellation from Paint.
FromScriptLogger
A logger directed at the constellation from content processes #[derive(Clone)]
InitialConstellationState
State needed to construct a constellation.
NewScriptEventLoopProcessInfo
All of the information necessary to create a new script EventLoop in a new process.

Enums

ConstellationToEmbedderMsg
Messages sent from the Constellation to the embedder.
UnprivilegedContent

Functions

content_process_sandbox_profile
Our content process sandbox profile on Linux. As restrictive as possible.