pub struct Constellation<STF, SWF> {
pub script_to_devtools_callback: OnceCell<Option<GenericCallback<ScriptToDevtoolsControlMsg>>>,
/* private fields */
}Expand description
The Constellation itself. In the servo browser, there is one
constellation, which maintains all of the browser global data.
In embedded applications, there may be more than one constellation,
which are independent of each other.
The constellation may be in a different process from the pipelines, and communicates using IPC.
It is parameterized over a LayoutThreadFactory and a
ScriptThreadFactory (which in practice are implemented by
LayoutThread in the layout crate, and ScriptThread in
the script crate). Script and layout communicate using a Message
type.
Fields
script_to_devtools_callback: OnceCell<Option<GenericCallback<ScriptToDevtoolsControlMsg>>>A (potentially) IPC-based channel to the developer tools, if enabled. This allows
EventLoops to send messages to then. Shared with all EventLoops.
Implementations
Sourceimpl<STF, SWF> Constellation<STF, SWF>where
STF: ScriptThreadFactory,
SWF: ServiceWorkerManagerFactory,
impl<STF, SWF> Constellation<STF, SWF>where
STF: ScriptThreadFactory,
SWF: ServiceWorkerManagerFactory,
Sourcepub fn start(
embedder_to_constellation_receiver: Receiver<EmbedderToConstellationMessage>,
state: InitialConstellationState,
layout_factory: Arc<dyn LayoutFactory>,
random_pipeline_closure_probability: Option<f32>,
random_pipeline_closure_seed: Option<usize>,
hard_fail: bool,
)
pub fn start( embedder_to_constellation_receiver: Receiver<EmbedderToConstellationMessage>, state: InitialConstellationState, layout_factory: Arc<dyn LayoutFactory>, random_pipeline_closure_probability: Option<f32>, random_pipeline_closure_seed: Option<usize>, hard_fail: bool, )
Create a new constellation thread.