pub struct InitialConstellationState {Show 17 fields
pub embedder_proxy: EmbedderProxy,
pub constellation_to_embedder_proxy: GenericEmbedderProxy<ConstellationToEmbedderMsg>,
pub paint_proxy: PaintProxy,
pub devtools_sender: Option<Sender<DevtoolsControlMsg>>,
pub system_font_service: Arc<SystemFontServiceProxy>,
pub public_resource_threads: ResourceThreads,
pub private_resource_threads: ResourceThreads,
pub public_storage_threads: StorageThreads,
pub private_storage_threads: StorageThreads,
pub time_profiler_chan: ProfilerChan,
pub mem_profiler_chan: ProfilerChan,
pub webrender_external_image_id_manager: WebRenderExternalImageIdManager,
pub webgl_threads: Option<WebGLThreads>,
pub webxr_registry: Option<Registry>,
pub privileged_urls: Vec<ServoUrl>,
pub async_runtime: Box<dyn AsyncRuntime>,
pub wake_lock_provider: Box<dyn WakeLockDelegate>,
}Expand description
State needed to construct a constellation.
Fields
embedder_proxy: EmbedderProxyA channel through which messages can be sent to the embedder. This is not used by the Constellation
itself but only needed to create an EventLoop.
Messages from the Constellation to the embedder are sent using the constellation_to_embedder_proxy
constellation_to_embedder_proxy: GenericEmbedderProxy<ConstellationToEmbedderMsg>A channel through which messages can be sent to the embedder.
paint_proxy: PaintProxyA channel through which messages can be sent to Paint in-process.
devtools_sender: Option<Sender<DevtoolsControlMsg>>A channel to the developer tools, if applicable.
system_font_service: Arc<SystemFontServiceProxy>A proxy to the SystemFontService which manages the list of system fonts.
public_resource_threads: ResourceThreadsA channel to the resource thread.
private_resource_threads: ResourceThreadsA channel to the resource thread.
public_storage_threads: StorageThreadsA channel to the storage thread.
private_storage_threads: StorageThreadsA channel to the storage thread.
time_profiler_chan: ProfilerChanA channel to the time profiler thread.
mem_profiler_chan: ProfilerChanA channel to the memory profiler thread.
webrender_external_image_id_manager: WebRenderExternalImageIdManagerA WebRenderExternalImageIdManager used to lazily start up the WebGPU threads.
webgl_threads: Option<WebGLThreads>Entry point to create and get channels to a WebGLThread.
webxr_registry: Option<Registry>The XR device registry
privileged_urls: Vec<ServoUrl>A list of URLs that can access privileged internal APIs.
async_runtime: Box<dyn AsyncRuntime>The async runtime.
wake_lock_provider: Box<dyn WakeLockDelegate>The wake lock provider for acquiring and releasing OS-level screen wake locks.